@@ -39,7 +39,7 @@ except ImportError:
         file=sys.stderr,
     )
     print(
-        ("try running :" "python setup.py build_ext --inplace -c mingw32"),
+        ("try running: python setup.py build_ext --inplace"),
         file=sys.stderr,
     )
     raise
@@ -169,6 +169,8 @@ class QuadGridItem(RawImageItem):
             xMap: X axis scale map
             yMap: Y axis scale map
         """
+        if self.warn_if_non_linear_scale(painter, canvasRect):
+            return
         self._offscreen[...] = np.uint32(0)
         dest = _scale_quads(
             self.X,
@@ -294,6 +296,8 @@ class Histogram2DItem(BaseImageItem):
             xMap: X axis scale map
             yMap: Y axis scale map
         """
+        if self.warn_if_non_linear_scale(painter, canvasRect):
+            return
         computation = self.histparam.computation
         i1, j1, i2, j2 = src_rect
 
@@ -340,7 +344,7 @@ class Histogram2DItem(BaseImageItem):
             return BaseImageItem.draw_image(self, *args)
 
         if self.fill_canvas:
-            x1, y1, x2, y2 = canvasRect.getCoords()
+            x1, y1, x2, y2 = canvasRect.toAlignedRect().getCoords()
             drawfunc(painter, canvasRect, src_rect, (x1, y1, x2, y2), xMap, yMap)
         else:
             dst_rect = tuple([int(i) for i in dst_rect])
