@@ -16,7 +16,6 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
@@ -83,7 +82,7 @@ class AbstractLabelItem(QwtPlotItem):
             self.labelparam = LabelParam(_("Label"), icon="label.png")
         else:
             self.labelparam = labelparam
-            self.labelparam.update_label(self)
+            self.labelparam.update_item(self)
         self._can_select = True
         self._can_resize = False
         self._can_move = True
@@ -97,7 +96,7 @@ class AbstractLabelItem(QwtPlotItem):
             option: Option
         """
         self.labelparam.read_config(CONF, section, option)
-        self.labelparam.update_label(self)
+        self.labelparam.update_item(self)
 
     def __reduce__(self) -> tuple[type, tuple]:
         """Return a tuple containing the constructor and its arguments"""
@@ -126,7 +125,7 @@ class AbstractLabelItem(QwtPlotItem):
         """
         self.labelparam = LabelParam(_("Label"), icon="label.png")
         reader.read("labelparam", instance=self.labelparam)
-        self.labelparam.update_label(self)
+        self.labelparam.update_item(self)
         if isinstance(self.G, np.ndarray):
             self.G = tuple(self.G)
 
@@ -207,6 +206,22 @@ class AbstractLabelItem(QwtPlotItem):
             y0 = yMap.transform(self.G[1])
             return x0, y0
 
+    def get_icon_name(self) -> str:
+        """Return the icon name
+
+        Returns:
+            Icon name
+        """
+        return self._icon_name
+
+    def set_icon_name(self, icon_name: str) -> None:
+        """Set the icon name
+
+        Args:
+            icon_name: Icon name
+        """
+        self._icon_name = icon_name
+
     def set_selectable(self, state: bool) -> None:
         """Set item selectable state
 
@@ -333,7 +348,7 @@ class AbstractLabelItem(QwtPlotItem):
         highlight the fact that it's not selected anymore
         """
         self.selected = False
-        self.labelparam.update_label(self)
+        self.labelparam.update_item(self)
         self.invalidate_plot()
 
     def hit_test(self, pos: QPointF) -> tuple[float, float, bool, None]:
@@ -407,7 +422,7 @@ class AbstractLabelItem(QwtPlotItem):
             itemparams: Item parameters
         """
         update_dataset(self.labelparam, itemparams.get("LabelParam"), visible_only=True)
-        self.labelparam.update_label(self)
+        self.labelparam.update_item(self)
         if self.selected:
             self.select()
 
@@ -497,6 +512,7 @@ class LabelItem(AbstractLabelItem):
     """
 
     __implements__ = (IBasePlotItem, ISerializableType)
+    _icon_name = "label.png"
 
     def __init__(
         self, text: str | None = None, labelparam: LabelParam | None = None
@@ -505,7 +521,6 @@ class LabelItem(AbstractLabelItem):
         self.text = QG.QTextDocument()
         self.marker: qwt.symbol.QwtSymbol | None = None
         super().__init__(labelparam)
-        self.setIcon(get_icon("label.png"))
 
     def __reduce__(self) -> tuple[type, tuple]:
         """Return a tuple containing the constructor and its arguments"""
@@ -645,6 +660,7 @@ class LegendBoxItem(AbstractLabelItem):
     """
 
     __implements__ = (IBasePlotItem, ISerializableType)
+    _icon_name = "legend.png"
 
     def __init__(self, labelparam: LabelParam = None) -> None:
         self.font = None
@@ -652,7 +668,6 @@ class LegendBoxItem(AbstractLabelItem):
         super().__init__(labelparam)
         # saves the last computed sizes
         self.sizes = 0.0, 0.0, 0.0, 0.0
-        self.setIcon(get_icon("legend.png"))
 
     def types(self) -> tuple[type[IItemType], ...]:
         """Returns a group or category for this item.
@@ -837,7 +852,7 @@ class LegendBoxItem(AbstractLabelItem):
         update_dataset(
             self.labelparam, itemparams.get("LegendParam"), visible_only=True
         )
-        self.labelparam.update_label(self)
+        self.labelparam.update_item(self)
         if self.selected:
             self.select()
 
