@@ -42,6 +42,7 @@ from plotpy.items import (
     AnnotatedEllipse,
     AnnotatedObliqueRectangle,
     AnnotatedPoint,
+    AnnotatedPolygon,
     AnnotatedRectangle,
     AnnotatedSegment,
     BaseImageItem,
@@ -444,6 +445,12 @@ class BasePlot(qwt.QwtPlot):
                 # This happens when object has already been deleted
                 pass
 
+    def update_color_mode(self) -> None:
+        """Color mode was updated, update plot widget accordingly"""
+        self.grid.gridparam.read_config(CONF, self.options.section, "grid")
+        self.grid.gridparam.update_grid(self.grid)
+        self.replot()
+
     def on_active_curve(self, x: float, y: float) -> tuple[float, float]:
         """
         Callback called when the active curve is moved
@@ -1315,7 +1322,7 @@ class BasePlot(qwt.QwtPlot):
         zlist = sorted(
             [_it.z() for _it in self.items if _it.z() >= zoffset] + [zoffset - 1]
         )
-        dzlist = np.argwhere(np.diff(zlist) > 1)
+        dzlist = np.argwhere(np.diff(zlist) > 1).flatten()
         if len(dzlist) == 0:
             z = max(zlist) + 1
         else:
@@ -1890,7 +1897,9 @@ class BasePlot(qwt.QwtPlot):
         dataset = itemparams.get("AxesParam")
         if dataset is not None:
             active_item = self.get_active_item()
-            dataset.update_item(active_item)
+            if active_item is not None:
+                # active_item may be None when dealing with non-selectable items only
+                dataset.update_item(active_item)
 
     def edit_plot_parameters(self, key: str) -> None:
         """
@@ -2363,3 +2372,4 @@ BasePlot.register_autoscale_type(AnnotatedEllipse)
 BasePlot.register_autoscale_type(AnnotatedObliqueRectangle)
 BasePlot.register_autoscale_type(AnnotatedSegment)
 BasePlot.register_autoscale_type(AnnotatedPoint)
+BasePlot.register_autoscale_type(AnnotatedPolygon)
